#include "timer.h"
#include "movlist.h"

enum {COMPUTER_BLACK, COMPUTER_WHITE, AUTOPLAY, ANALYSE, HUMANS };

typedef struct board {
  GtkWidget *canvas;
  gboolean flip;
  gint mode;
  GtkWidget *whitename;
  GtkWidget *blackname;   
  timer *whitetime;   
  timer *blacktime;   
  GtkWidget *messages; 
  MoveList *movelist;
  GtkWidget *command;
} Board;

Board board;

GtkWidget * gnomechess_board_new(void);
void gnomechess_board_set_flip(gboolean f);
void gnomechess_board_flip(void);
void gnomechess_board_update(void);